==> plugin.video.fen-2.0.17.zip: plugin.video.fen/resources/lib/windows/next_episode_dialog.py <==
# -*- coding: utf-8 -*-
import xbmc
from windows.base_dialog import BaseDialog
from modules.nav_utils import build_url
from modules.kodi_utils import sleep
from modules.utils import local_string as ls
# from modules.utils import logger

click_actions = {10: 'close', 11: 'play', 12: 'cancel'}
confirm_actions = {10: True, 11: False}

class NextEpisodeXML(BaseDialog):
	def __init__(self, *args, **kwargs):
		BaseDialog.__init__(self, args)
		self.player = xbmc.Player()
		self.closed = False
		self.meta = kwargs.get('meta')
		self.function = kwargs.get('function', 'next_ep')# or 'confirm'
		if self.function == 'next_ep':
			self.actions = click_actions
			self.selected = 'close'
		else:
			self.actions = confirm_actions
			self.selected = False
		self.set_properties()

	def onInit(self):
		self.monitor()

	def run(self):
		self.doModal()
		return self.selected

	def onAction(self, action):
		if action in self.closing_actions:
			self.closed = True
			self.close()

	def onClick(self, controlID):
		self.closed = True
		self.selected = self.actions[controlID]
		self.close()

	def set_properties(self):
		self.setProperty('tikiskins.title', self.meta['title'])
		self.setProperty('tikiskins.poster', self.meta['poster'])
		self.setProperty('tikiskins.fanart', self.meta['fanart'])
		self.setProperty('tikiskins.nextep_function', self.function)
		if self.function == 'next_ep':
			self.setProperty('tikiskins.next_episode', '[B]%s - %02dx%02d[/B] - %s' % (self.meta['title'], self.meta['season'], self.meta['episode'], self.meta['ep_name']))
		else:
			self.setProperty('tikiskins.title', self.meta['title'])

	def monitor(self):
		progress_bar = self.getControl(5000)
		if self.function == 'next_ep':
			total_time = self.player.getTotalTime()
			remaining = total_time - self.player.getTime()
			while self.player.isPlaying():
				try:
					if self.closed: break
					current_time = self.player.getTime()
					current_point = ((int(total_time) - int(current_time)) / float(remaining)) * 100
					progress_bar.setPercent(current_point)
					sleep(1000)
				except: pass
		else:
			for current_point in range(100, 0, -5):
				try:
					if self.closed: break
					if current_point == 0: break
					progress_bar.setPercent(current_point)
					sleep(1000)
				except: pass
		self.close()

==> plugin.video.fen-2.0.18.zip: plugin.video.fen/resources/lib/windows/next_episode_dialog.py <==
# -*- coding: utf-8 -*-
import xbmc
from windows.base_dialog import BaseDialog
# from modules.utils import logger

click_actions = {10: 'close', 11: 'play', 12: 'cancel'}
confirm_actions = {10: True, 11: False}

class NextEpisodeXML(BaseDialog):
	def __init__(self, *args, **kwargs):
		BaseDialog.__init__(self, args)
		self.closed = False
		self.meta = kwargs.get('meta')
		self.function = kwargs.get('function', 'next_ep')# or 'confirm'
		if self.function == 'next_ep':
			self.actions = click_actions
			self.selected = 'close'
		else:
			self.actions = confirm_actions
			self.selected = False
		self.set_properties()

	def onInit(self):
		self.monitor()

	def run(self):
		self.doModal()
		return self.selected

	def onAction(self, action):
		if action in self.closing_actions:
			self.closed = True
			self.close()

	def onClick(self, controlID):
		self.closed = True
		self.selected = self.actions[controlID]
		self.close()

	def set_properties(self):
		self.setProperty('tikiskins.title', self.meta['title'])
		self.setProperty('tikiskins.poster', self.meta['poster'])
		self.setProperty('tikiskins.fanart', self.meta['fanart'])
		self.setProperty('tikiskins.nextep_function', self.function)
		if self.function == 'next_ep':
			self.setProperty('tikiskins.next_episode', '[B]%s - %02dx%02d[/B] - %s' % (self.meta['title'], self.meta['season'], self.meta['episode'], self.meta['ep_name']))
		else:
			self.setProperty('tikiskins.title', self.meta['title'])

	def monitor(self):
		progress_bar = self.getControl(5000)
		if self.function == 'next_ep':
			total_time = self.player.getTotalTime()
			remaining = total_time - self.player.getTime()
			while self.player.isPlaying():
				try:
					if self.closed: break
					current_time = self.player.getTime()
					current_point = ((int(total_time) - int(current_time)) / float(remaining)) * 100
					progress_bar.setPercent(current_point)
					self.sleep(1000)
				except: pass
		else:
			for current_point in range(100, 0, -5):
				try:
					if self.closed: break
					if current_point == 0: break
					progress_bar.setPercent(current_point)
					self.sleep(1000)
				except: pass
		self.close()
